--[[

An simple example on how to use urlLoader to interact with Scoreoid.

Must register at scoreoid.net and create game for API and game IDs.

Similar methods will work with Game Minion or other RESTful api based services.

Requires Json.lua to decode json file format to lua table.

]]



api = "PUT YOUR API CODE HERE" -- unique API key given to every user of Scoreoid
gID = "PUT YOUR GAME ID HERE" -- unique ID given to every game registered.
response = "json" -- format of response.  Supports json or xml.

function createPlayer(username, password) -- creates a new player using username and password

	-- create headers for HTTP request.  Honestly do not quite understand what these do.
	-- must be in table format
	local headers = {
	["Authorization"] = "Basic",
	["Content-Type"]  = "application/x-www-form-urlencoded",
	}
	-- using a POST method as apposed to GET or PUT methods
	local method = UrlLoader.POST
	-- Body is a string that contains all data sent to API
	-- follows format of "firstKey=value&secondKey=secondValue...ect
	local body = "api_key="..api.."&game_id="..gID.."&response="..response.."&username="..username.."&password="..password
	--url of method.  Provided in Scoreoid docs
	local url = "https://www.scoreoid.com/api/createPlayer"
	
	--create a new urlLoader intance.
	local loader = UrlLoader.new(url, method, headers, body)
	
	-- define event functions for urlLoader
	local function onComplete(event)
		print(event.data)
	end

	local function onError()
		print("error")
		end

	local function onProgress(event)
		print("progress: " .. event.bytesLoaded .. " of " .. event.bytesTotal)
	end
	
	--add listeners to loader for events
	loader:addEventListener(Event.COMPLETE, onComplete)
	loader:addEventListener(Event.ERROR, onError)
	loader:addEventListener(Event.PROGRESS, onProgress)
end

--the following functions follow same format as above
--Not all HTTP requests will be POST methods, but most seem to be with Scoreoid.
function getPlayer(username, password)

	local headers = {
	["Authorization"] = "Basic",
	["Content-Type"]  = "application/x-www-form-urlencoded",
	}
	
	local method = UrlLoader.POST
	local body = "api_key="..api.."&game_id="..gID.."&response="..response.."&username="..username.."&password="..password
	local url = "https://www.scoreoid.com/api/getPlayer"
	

	local loader = UrlLoader.new(url, method, headers, body)
	
	local function onComplete(event)
		print(event.data)
	end

	local function onError()
		print("error")
		end

	local function onProgress(event)
		print("progress: " .. event.bytesLoaded .. " of " .. event.bytesTotal)
	end
	
	loader:addEventListener(Event.COMPLETE, onComplete)
	loader:addEventListener(Event.ERROR, onError)
	loader:addEventListener(Event.PROGRESS, onProgress)

end

function createScore(username, score) -- accepts string and number

	local headers = {
	["Authorization"] = "Basic",
	["Content-Type"]  = "application/x-www-form-urlencoded",
	}
	
	local method = UrlLoader.POST
	local body = "api_key="..api.."&game_id="..gID.."&response="..response.."&username="..username.."&score="..score
	local url = "https://www.scoreoid.com/api/createScore"
	

	local loader = UrlLoader.new(url, method, headers, body)
	
	local function onComplete(event)
		print(event.data)
	end

	local function onError()
		print("error")
		end

	local function onProgress(event)
		print("progress: " .. event.bytesLoaded .. " of " .. event.bytesTotal)
	end
	
	loader:addEventListener(Event.COMPLETE, onComplete)
	loader:addEventListener(Event.ERROR, onError)
	loader:addEventListener(Event.PROGRESS, onProgress)

end

function getBestScores(orderBy, order) -- score or date, asc or desc

	local headers = {
	["Authorization"] = "Basic",
	["Content-Type"]  = "application/x-www-form-urlencoded",
	}
	
	local method = UrlLoader.POST
	local body = "api_key="..api.."&game_id="..gID.."&response="..response.."&order_by="..orderBy.."&order="..order
	local url = "https://www.scoreoid.com/api/getBestScores"
	

	local loader = UrlLoader.new(url, method, headers, body)
	
	local function onComplete(event)
		print("The event Data is:")
		print(event.data)
		print("....convert to table.....")
		--decode Json response into lua table
		local t = Json.Decode(event.data)
		print("There are "..#t.." entries in the table")
		--loop to print all entries to console
		for i = 1, #t, 1 do -- from 1 to number of players, moving by 1....
			print("USERNAME:  "..t[i].Player.username.."	".."SCORE:  "..t[i].Score.score)
			end
	end

	local function onError()
		print("error")
		end

	local function onProgress(event)
		print("progress: " .. event.bytesLoaded .. " of " .. event.bytesTotal)
	end
	
	loader:addEventListener(Event.COMPLETE, onComplete)
	loader:addEventListener(Event.ERROR, onError)
	loader:addEventListener(Event.PROGRESS, onProgress)

end

--createScore("testUnit", 3200)
getBestScores("score", "desc")